[RFC] Spelling fixed

Thomas Meyer thomas at m3y3r.de
Fri Mar 23 15:55:58 PDT 2012


# HG changeset patch
# User thomas at m3y3r.de
# Date 1332453344 -3600
# Node ID c630651c44ab4a2973dacbd99007ce527cca6ed4
# Parent  7222dd21241e62af4997d5f25539cce0a0ee31aa
Spelling fixes.

diff -r 7222dd21241e -r c630651c44ab tests/netx/jnlp_testsengine/net/sourceforge/jnlp/ServerAccess.java
--- a/tests/netx/jnlp_testsengine/net/sourceforge/jnlp/ServerAccess.java	Thu Mar 22 22:48:18 2012 +0100
+++ b/tests/netx/jnlp_testsengine/net/sourceforge/jnlp/ServerAccess.java	Thu Mar 22 22:55:44 2012 +0100
@@ -67,16 +67,16 @@
 
 /**
  *
- * This class provides access to virtual server and stuff arround.
- * It can find unoccupied port, start server, provides its singleton instantion, lunch paralel instantions,
+ * This class provides access to virtual server and stuff around.
+ * It can find unoccupied port, start server, provides its singleton instantiation, lunch parallel instantiations,
  * read location of installed (tested javaws) see javaws.build.bin java poperty,
- * location of server www root on filesystem (see test.server.dir java property),
+ * location of server www root on file system (see test.server.dir java property),
  * stubs for lunching javaws and for locating resources and read resources.
  *
  * It can also execute processes with timeout (@see PROCESS_TIMEOUT) (used during lunching javaws)
- * Some protected apis are exported because public clases in this package are put to be tested by makefile.
+ * Some protected apis are exported because public classes in this package are put to be tested by makefile.
  *
- * There are inclued tescases which show some basic usages.
+ * There are included test cases which show some basic usages.
  *
  *
  */
@@ -84,11 +84,11 @@
 
     public static final long NANO_TIME_DELIMITER=1000000l;
     /**
-     * java property which value containig path to default (makefile by) directory with deployed resources
+     * java property which value containing path to default (makefile by) directory with deployed resources
      */
     public static final String TEST_SERVER_DIR = "test.server.dir";
     /**
-     * java property which value containig path to installed (makefile by) javaws binary
+     * java property which value containing path to installed (makefile by) javaws binary
      */
     public static final String JAVAWS_BUILD_BIN = "javaws.build.bin";
     public static final String DEFAULT_LOCALHOST_NAME = "localhost";
@@ -106,7 +106,7 @@
      */
     public static int READ_TIMEOUT = 1000;
     /**
-     * timeout in ms to let process to finish, before assasin wil kill it.
+     * timeout in ms to let process to finish, before assassin will kill it.
      * This can be changed in runtime, but will affect all following tasks
      */
     public static long PROCESS_TIMEOUT = 20 * 1000;//ms
@@ -127,8 +127,8 @@
     /**
      * utility method to find random free port
      *
-     * @return - foud random free port
-     * @throws IOException - if socket can't be openned or no free port exists
+     * @return - found random free port
+     * @throws IOException - if socket can't be opened or no free port exists
      */
     public static int findFreePort()
             throws IOException {
@@ -151,7 +151,7 @@
 
     /**
      *
-     * @return cahed instance. If none, then creates new
+     * @return cached instance. If none, then creates new
      */
     public static ServerLauncher getInstance() {
         if (server == null) {
@@ -163,7 +163,7 @@
     /**
      *
      * @return new not cached iserver instance on random port,
-     * usefull for testing application loading from different url then base
+     * useful for testing application loading from different url then base
      */
     public static ServerLauncher getIndependentInstance() {
         String dir = (System.getProperty(TEST_SERVER_DIR));
@@ -173,7 +173,7 @@
     /**
      *
      * @return new not cached iserver instance on random port upon custom www root directory,
-     * usefull for testing application loading from different url then base
+     * useful for testing application loading from different url then base
      */
     public static ServerLauncher getIndependentInstance(String dir) {
 
@@ -318,7 +318,7 @@
 
     /**
      *
-     * @return port on which is runing cached server. If non singleton instance is runnig, new is created.
+     * @return port on which is running cached server. If non singleton instance is running, new is created.
      */
     public int getPort() {
         if (server == null) {
@@ -331,7 +331,7 @@
 
     /**
      *
-     * @return directory upon which is runing cached server. If non singleton instance is runnig, new is created.
+     * @return directory upon which is running cached server. If non singleton instance is running, new is created.
      */
     public File getDir() {
         if (server == null) {
@@ -343,7 +343,7 @@
 
     /**
      *
-     * @return url pointing to cached server resource. If non singleton instance is runnig, new is created.
+     * @return url pointing to cached server resource. If non singleton instance is running, new is created.
      */
     public URL getUrl(String resource) throws MalformedURLException {
         if (server == null) {
@@ -355,7 +355,7 @@
 
     /**
      *
-     * @return url pointing to cached server . If non singleton instance is runnig, new is created.
+     * @return url pointing to cached server . If non singleton instance is running, new is created.
      */
     public URL getUrl() throws MalformedURLException {
         return getUrl("");
@@ -364,7 +364,7 @@
 
     /**
      *
-     * @return weather cached server is alive. If non singleton instance is runnig, new is created.
+     * @return weather cached server is alive. If non singleton instance is running, new is created.
      */
     public boolean isRunning() {
         if (server == null) {
@@ -380,7 +380,7 @@
      * 
      * @param resource to be located on cached server
      * @return individual bytes of resource
-     * @throws IOException if connection cant be established or resource do not exists
+     * @throws IOException if connection can't be established or resource do not exists
      */
     public ByteArrayOutputStream getResourceAsBytes(String resource) throws IOException {
         return getResourceAsBytes(getUrl(resource));
@@ -391,7 +391,7 @@
      * 
      * @param resource to be located on cached server
      * @return string constructed from  resource
-     * @throws IOException if connection cant be established or resource do not exists
+     * @throws IOException if connection can't be established or resource do not exists
      */
     public String getResourceAsString(String resource) throws IOException {
         return getResourceAsString(getUrl(resource));
@@ -402,7 +402,7 @@
      * 
      * @param input stream to be read
      * @return individual bytes of resource
-     * @throws IOException if connection cant be established or resource do not exists
+     * @throws IOException if connection can't be established or resource do not exists
      */
     public static ByteArrayOutputStream getBytesFromStream(InputStream is) throws IOException {
         ByteArrayOutputStream buffer = new ByteArrayOutputStream();
@@ -420,7 +420,7 @@
      * 
      * @param input stream
      * @return stream as string
-     * @throws IOException if connection cant be established or resource do not exists
+     * @throws IOException if connection can't be established or resource do not exists
      */
     public static String getContentOfStream(InputStream is) throws IOException {
         try {
@@ -446,7 +446,7 @@
      * 
      * @param resource to be located on any url
      * @return individual bytes of resource
-     * @throws IOException if connection cant be established or resource do not exists
+     * @throws IOException if connection can't be established or resource do not exists
      */
     public static ByteArrayOutputStream getResourceAsBytes(URL u) throws IOException {
         HttpURLConnection connection = (HttpURLConnection) u.openConnection();
@@ -462,9 +462,9 @@
     /**
      * utility method which can read string of resource from any url
      * 
-     * @param resource to be located onany url
+     * @param resource to be located on any url
      * @return resource as string
-     * @throws IOException if connection cant be established or resource do not exists
+     * @throws IOException if connection can't be established or resource do not exists
      */
     public static String getResourceAsString(URL u) throws IOException {
         HttpURLConnection connection = (HttpURLConnection) u.openConnection();
@@ -493,7 +493,7 @@
     /**
      * wrapping method to executeProcess (eg: javaws -headless http://localhost:port/resource)
      * will execute default javaws (@see JAVAWS_BUILD_BIN) upon default url upon cached server (@see SERVER_NAME @see getPort(), @see getInstance())
-     * with parameter -headles (no gui, no asking)
+     * with parameter -headless (no gui, no asking)
      * @param resource  name of resource
      * @return result what left after running this process
      * @throws Exception
@@ -505,9 +505,9 @@
     /**
      * wrapping method to executeProcess (eg: javaws arg arg -headless http://localhost:port/resource)
      * will execute default javaws (@see JAVAWS_BUILD_BIN) upon default url upon cached server (@see SERVER_NAME @see getPort(), @see getInstance())
-     * with parameter -headles (no gui, no asking)
+     * with parameter -headless (no gui, no asking)
      * @param resource  name of resource
-     * @param otherargs other arguments to be added to hedales one
+     * @param otherargs other arguments to be added to headless one
      * @return result what left after running this process
      * @throws Exception
      */
@@ -581,19 +581,19 @@
          return  executeProcess(args, null);
      }
     /**
-     * utility method to lunch process, get its stdou/stderr, its return value and to kill it if runing to long (@see PROCESS_TIMEOUT)
+     * utility method to lunch process, get its stdout/stderr, its return value and to kill it if running to long (@see PROCESS_TIMEOUT)
      *
      *
      * Small bacground:
-     * This method creates thread inside which exec will be executed. Then creates assasin thread with given timeout to kill the previously created thread if necessary.
-     * Starts assasin thread, starts process thread. Wait untill process is running, then starts content readers.
+     * This method creates thread inside which exec will be executed. Then creates assassin thread with given timeout to kill the previously created thread if necessary.
+     * Starts assassin thread, starts process thread. Wait until process is running, then starts content readers.
      * Closes input of process.
-     * Wait until process is running (no metter if it teminate itself (correctly or badly), or is terminated by its assasin.
-     * Construct result from readed stdout, stderr, process return value, assasin sucessfulity
+     * Wait until process is running (no matter if it terminate itself (correctly or badly), or is terminated by its assassin.
+     * Construct result from readed stdout, stderr, process return value, assassin successfully
      *
      * @param args binary with args to be executed
      * @param dir optional, directory where this process will run
-     * @return what left from process - proces sitself, its stdout, stderr and return value and weather it was terminated by assasin.
+     * @return what left from process - process itself, its stdout, stderr and return value and weather it was terminated by assassin.
      * @throws Exception
      */
     public static ProcessResult executeProcess(final List<String> args,File dir) throws Exception {
@@ -626,8 +626,8 @@
 
     /**
      *
-     * wrapper arround Runtime.getRuntime().exec(...) which ensures taht process is run inside its own, by us controlled, thread.
-     * Proces sbuilder caused som einexpected and wired behaviour:/
+     * wrapper around Runtime.getRuntime().exec(...) which ensures that process is run inside its own, by us controlled, thread.
+     * Process builder caused some unexpected and wired behavior :/
      */
     private static class ThreadedProcess extends Thread {
 
@@ -685,10 +685,10 @@
                     p = r.exec(args.toArray(new String[0]),new String[0], dir);
                 }
                 exitCode = p.waitFor();
-                Thread.sleep(500);//this is giving to fastly done proecesses's e/o readers time to read all. I would like to know better solution :-/
+                Thread.sleep(500); //this is giving to fast done processes's e/o readers time to read all. I would like to know better solution :-/
             } catch (Exception ex) {
                 if (ex instanceof InterruptedException) {
                     //add to the set of terminated threadedproceses
                     terminated.add(this);
                 } else {
                     throw new RuntimeException(ex);
@@ -700,8 +700,8 @@
     }
 
     /**
-     * wrapper arround tiny http server to separate lunch configgurations and servers.
-     * to allow terminations and stuff arround.
+     * wrapper around tiny http server to separate lunch configurations and servers.
+     * to allow terminations and stuff around.
      */
     public static class ServerLauncher implements Runnable {
 
@@ -848,7 +848,7 @@
     }
 
     /**
-     * class which timeout any ThreadedProcess. This killing of 'theread with process' replaced not working process.destroy().
+     * class which timeout any ThreadedProcess. This killing of 'thread with process' replaced not working process.destroy().
      */
     private static class ProcessAssasin extends Thread {
 
@@ -861,7 +861,7 @@
         /**
          *
          * @param p
-         * @param timeout - time to die in milis
+         * @param timeout - time to die in milliseconds
          */
         public ProcessAssasin(ThreadedProcess p, long timeout) {
             this.p = (p);
@@ -945,7 +945,7 @@
     }
 
     /**
-     * Class to read content of stdou/err of process, and to cooperate with its running/terminated/finished statuses.
+     * Class to read content of stdout/stderr of process, and to cooperate with its running/terminated/finished statuses.
      */
     private static class ContentReader implements Runnable {
 
@@ -685,10 +685,10 @@
             } catch (Exception ex) {
                 if (ex instanceof InterruptedException) {
-                    //add to the set of terminated threadedproceses
+                    //add to the set of terminated threaded processes
                     terminated.add(this);
                 } else {





More information about the distro-pkg-dev mailing list